@@ -36,4 +36,4 @@ def test_pep8():
     warnings = pep8.get_count('W')
     message = 'pep8: %d errors / %d warnings' % (errors, warnings)
     print(message)
-    assert(errors + warnings == 0, message)
+    assert errors + warnings == 0, message
